@@ -41,31 +41,38 @@ try:
 except ImportError:
     from md5 import new as md5
 
-from fedora.client import AppError, BaseClient, FasProxyClient, \
-        FedoraClientError, FedoraServiceError
-from fedora import __version__ 
+from fedora.client import (
+    AppError, BaseClient, FasProxyClient,
+    FedoraClientError, FedoraServiceError
+)
+
+from fedora import __version__
 
 ### FIXME: To merge:
 # /usr/bin/fasClient from fas
 # API from Will Woods
 # API from MyFedora
 
+
 class FASError(FedoraClientError):
     '''FAS Error'''
     pass
 
+
 class CLAError(FASError):
     '''CLA Error'''
     pass
 
-USERFIELDS = ['affiliation', 'bugzilla_email', 'certificate_serial',
-        'comments', 'country_code', 'creation', 'email', 'emailtoken',
-        'facsimile', 'gpg_keyid', 'human_name', 'id', 'internal_comments',
-        'ircnick', 'latitude', 'last_seen', 'longitude', 'password',
-        'password_changed', 'passwordtoken', 'postal_address', 'privacy',
-        'locale', 'ssh_key', 'status', 'status_change', 'telephone',
-        'unverified_email', 'timezone', 'username', 'security_question',
-        'security_answer', ]
+USERFIELDS = [
+    'affiliation', 'bugzilla_email', 'certificate_serial',
+    'comments', 'country_code', 'creation', 'email', 'emailtoken',
+    'facsimile', 'gpg_keyid', 'human_name', 'id', 'internal_comments',
+    'ircnick', 'latitude', 'last_seen', 'longitude', 'password',
+    'password_changed', 'passwordtoken', 'postal_address', 'privacy',
+    'locale', 'ssh_key', 'status', 'status_change', 'telephone',
+    'unverified_email', 'timezone', 'username', 'security_question',
+    'security_answer', ]
+
 
 class AccountSystem(BaseClient):
     '''An object for querying the Fedora Account System.
@@ -106,7 +113,7 @@ class AccountSystem(BaseClient):
     _valid_avatar_services = ['libravatar', 'gravatar']
 
     def __init__(self, base_url='https://admin.fedoraproject.org/accounts/',
-            *args, **kwargs):
+                 *args, **kwargs):
         '''Create the AccountSystem client object.
 
         :kwargs base_url: Base of every URL used to contact the server.
@@ -123,137 +130,141 @@ class AccountSystem(BaseClient):
             on the filesystem between runs.
         '''
         if 'useragent' not in kwargs:
-            kwargs['useragent'] = 'Fedora Account System Client/%s' \
-                    % __version__
+            kwargs['useragent'] = \
+                'Fedora Account System Client/%s' % __version__
+
         super(AccountSystem, self).__init__(base_url, *args, **kwargs)
         # We need a single proxy for the class to verify username/passwords
         # against.
         if not self.proxy:
             self.proxy = FasProxyClient(base_url, useragent=self.useragent,
-                    session_as_cookie=False, debug=self.debug,
-                    insecure=self.insecure)
+                                        session_as_cookie=False,
+                                        debug=self.debug,
+                                        insecure=self.insecure)
 
         # Preseed a list of FAS accounts with bugzilla addresses
         # This allows us to specify a different email for bugzilla than is
         # in the FAS db.  It is a hack, however, until FAS has a field for the
         # bugzilla address.
         self.__bugzilla_email = {
-                # Konstantin Ryabitsev: mricon@gmail.com
-                100029: 'icon@fedoraproject.org',
-                # Sean Reifschneider: jafo@tummy.com
-                100488: 'jafo-redhat@tummy.com',
-                # Karen Pease: karen-pease@uiowa.edu
-                100281: 'meme@daughtersoftiresias.org',
-                # Robert Scheck: redhat@linuxnetz.de
-                100093: 'redhat-bugzilla@linuxnetz.de',
-                # Scott Bakers: bakers@web-ster.com
-                100881: 'scott@perturb.org',
-                # Colin Charles: byte@aeon.com.my
-                100014: 'byte@fedoraproject.org',
-                # W. Michael Petullo: mike@flyn.org
-                100136: 'redhat@flyn.org',
-                # Elliot Lee: sopwith+fedora@gmail.com
-                100060: 'sopwith@redhat.com',
-                # Control Center Team: Bugzilla user but email doesn't exist
-                9908: 'control-center-maint@redhat.com',
-                # Máirín Duffy
-                100548: 'duffy@redhat.com',
-                # Muray McAllister: murray.mcallister@gmail.com
-                102321: 'mmcallis@redhat.com',
-                # William Jon McCann: mccann@jhu.edu
-                102489: 'jmccann@redhat.com',
-                # Matt Domsch's rebuild script -- bz email goes to /dev/null
-                103590: 'ftbfs@fedoraproject.org',
-                # Sindre Pedersen Bjørdal: foolish@guezz.net
-                100460 : 'sindrepb@fedoraproject.org',
-                # Jesus M. Rodriguez: jmrodri@gmail.com
-                102180: 'jesusr@redhat.com',
-                # Roozbeh Pournader: roozbeh@farsiweb.info
-                100350: 'roozbeh@gmail.com',
-                # Michael DeHaan: michael.dehaan@gmail.com
-                100603: 'mdehaan@redhat.com',
-                # Sebastian Gosenheimer: sgosenheimer@googlemail.com
-                103647: 'sebastian.gosenheimer@proio.com',
-                # Ben Konrath: bkonrath@redhat.com
-                101156: 'ben@bagu.org',
-                # Kai Engert: kaie@redhat.com
-                100399: 'kengert@redhat.com',
-                # William Jon McCann: william.jon.mccann@gmail.com
-                102952: 'jmccann@redhat.com',
-                # Simon Wesp: simon@w3sp.de
-                109464: 'cassmodiah@fedoraproject.org',
-                # Robert M. Albrecht: romal@gmx.de
-                101475: 'mail@romal.de',
-                # Mathieu Bridon: mathieu.bridon@gmail.com
-                100753: 'bochecha@fedoraproject.org',
-                # Davide Cescato: davide.cescato@iaeste.ch
-                123204: 'ceski@fedoraproject.org',
-                # Nick Bebout: nick@bebout.net
-                101458: 'nb@fedoraproject.org',
-                # Niels Haase: haase.niels@gmail.com
-                126862: 'arxs@fedoraproject.org',
-                # Thomas Janssen: th.p.janssen@googlemail.com
-                103110: 'thomasj@fedoraproject.org',
-                # Michael J Gruber: 'michaeljgruber+fedoraproject@gmail.com'
-                105113: 'mjg@fedoraproject.org',
-                # Juan Manuel Rodriguez Moreno: 'nushio@gmail.com'
-                101302: 'nushio@fedoraproject.org',
-                # Andrew Cagney: 'andrew.cagney@gmail.com'
-                102169: 'cagney@fedoraproject.org',
-                # Jeremy Katz: 'jeremy@katzbox.net'
-                100036: 'katzj@fedoraproject.org',
-                # Dominic Hopf: 'dmaphy@gmail.com'
-                124904: 'dmaphy@fedoraproject.org',
-                # Christoph Wickert: 'christoph.wickert@googlemail.com':
-                100271: 'cwickert@fedoraproject.org',
-                # Elliott Baron: 'elliottbaron@gmail.com'
-                106760: 'ebaron@fedoraproject.org',
-                # Thomas Spura: 'spurath@students.uni-mainz.de'
-                111433: 'tomspur@fedoraproject.org',
-                # Adam Miller: 'maxamillion@gmail.com'
-                110673: 'admiller@redhat.com',
-                # Garrett Holmstrom: 'garrett.holmstrom@gmail.com'
-                131739: 'gholms@fedoraproject.org',
-                # Tareq Al Jurf: taljurf.fedora@gmail.com
-                109863: 'taljurf@fedoraproject.org',
-                # Josh Kayse: jokajak@gmail.com
-                148243: 'jokajak@fedoraproject.org',
-                # Behdad Esfahbod: fedora@behdad.org
-                100102: 'behdad@fedoraproject.org',
-                # Daniel Bruno: danielbrunos@gmail.com
-                101608: 'dbruno@fedoraproject.org',
-                # Beth Lynn Eicher: bethlynneicher@gmail.com
-                148706: 'bethlynn@fedoraproject.org',
-                # Andre Robatino: andre.robatino@verizon.net
-                114970: 'robatino@fedoraproject.org',
-                # Jeff Sheltren: jeff@tag1consulting.com
-                100058: 'sheltren@fedoraproject.org',
-                # Josh Boyer: jwboyer@gmail.com
-                100115: 'jwboyer@redhat.com',
-                # Matthew Miller: mattdm@mattdm.org
-                100042: 'mattdm@redhat.com',
-                # Jamie Nguyen: j@jamielinux.com
-                160587: 'jamielinux@fedoraproject.org',
-                # Nikos Roussos: nikos@roussos.cc
-                144436: 'comzeradd@fedoraproject.org',
-                # Benedikt Schäfer: benedikt@schaefer-flieden.de
-                154726: 'ib54003@fedoraproject.org',
-                # Ricky Elrod: codeblock@elrod.me
-                139137: 'relrod@redhat.com',
-                # David Xie: david.scriptfan@gmail.com
-                167133: 'davidx@fedoraproject.org',
-                # Felix Schwarz: felix.schwarz@oss.schwarz.eu
-                103551: 'fschwarz@fedoraproject.org',
-                }
+            # Konstantin Ryabitsev: mricon@gmail.com
+            100029: 'icon@fedoraproject.org',
+            # Sean Reifschneider: jafo@tummy.com
+            100488: 'jafo-redhat@tummy.com',
+            # Karen Pease: karen-pease@uiowa.edu
+            100281: 'meme@daughtersoftiresias.org',
+            # Robert Scheck: redhat@linuxnetz.de
+            100093: 'redhat-bugzilla@linuxnetz.de',
+            # Scott Bakers: bakers@web-ster.com
+            100881: 'scott@perturb.org',
+            # Colin Charles: byte@aeon.com.my
+            100014: 'byte@fedoraproject.org',
+            # W. Michael Petullo: mike@flyn.org
+            100136: 'redhat@flyn.org',
+            # Elliot Lee: sopwith+fedora@gmail.com
+            100060: 'sopwith@redhat.com',
+            # Control Center Team: Bugzilla user but email doesn't exist
+            9908: 'control-center-maint@redhat.com',
+            # Máirín Duffy
+            100548: 'duffy@redhat.com',
+            # Muray McAllister: murray.mcallister@gmail.com
+            102321: 'mmcallis@redhat.com',
+            # William Jon McCann: mccann@jhu.edu
+            102489: 'jmccann@redhat.com',
+            # Matt Domsch's rebuild script -- bz email goes to /dev/null
+            103590: 'ftbfs@fedoraproject.org',
+            # Sindre Pedersen Bjørdal: foolish@guezz.net
+            100460: 'sindrepb@fedoraproject.org',
+            # Jesus M. Rodriguez: jmrodri@gmail.com
+            102180: 'jesusr@redhat.com',
+            # Roozbeh Pournader: roozbeh@farsiweb.info
+            100350: 'roozbeh@gmail.com',
+            # Michael DeHaan: michael.dehaan@gmail.com
+            100603: 'mdehaan@redhat.com',
+            # Sebastian Gosenheimer: sgosenheimer@googlemail.com
+            103647: 'sebastian.gosenheimer@proio.com',
+            # Ben Konrath: bkonrath@redhat.com
+            101156: 'ben@bagu.org',
+            # Kai Engert: kaie@redhat.com
+            100399: 'kengert@redhat.com',
+            # William Jon McCann: william.jon.mccann@gmail.com
+            102952: 'jmccann@redhat.com',
+            # Simon Wesp: simon@w3sp.de
+            109464: 'cassmodiah@fedoraproject.org',
+            # Robert M. Albrecht: romal@gmx.de
+            101475: 'mail@romal.de',
+            # Mathieu Bridon: mathieu.bridon@gmail.com
+            100753: 'bochecha@fedoraproject.org',
+            # Davide Cescato: davide.cescato@iaeste.ch
+            123204: 'ceski@fedoraproject.org',
+            # Nick Bebout: nick@bebout.net
+            101458: 'nb@fedoraproject.org',
+            # Niels Haase: haase.niels@gmail.com
+            126862: 'arxs@fedoraproject.org',
+            # Thomas Janssen: th.p.janssen@googlemail.com
+            103110: 'thomasj@fedoraproject.org',
+            # Michael J Gruber: 'michaeljgruber+fedoraproject@gmail.com'
+            105113: 'mjg@fedoraproject.org',
+            # Juan Manuel Rodriguez Moreno: 'nushio@gmail.com'
+            101302: 'nushio@fedoraproject.org',
+            # Andrew Cagney: 'andrew.cagney@gmail.com'
+            102169: 'cagney@fedoraproject.org',
+            # Jeremy Katz: 'jeremy@katzbox.net'
+            100036: 'katzj@fedoraproject.org',
+            # Dominic Hopf: 'dmaphy@gmail.com'
+            124904: 'dmaphy@fedoraproject.org',
+            # Christoph Wickert: 'christoph.wickert@googlemail.com':
+            100271: 'cwickert@fedoraproject.org',
+            # Elliott Baron: 'elliottbaron@gmail.com'
+            106760: 'ebaron@fedoraproject.org',
+            # Thomas Spura: 'spurath@students.uni-mainz.de'
+            111433: 'tomspur@fedoraproject.org',
+            # Adam Miller: 'maxamillion@gmail.com'
+            110673: 'admiller@redhat.com',
+            # Garrett Holmstrom: 'garrett.holmstrom@gmail.com'
+            131739: 'gholms@fedoraproject.org',
+            # Tareq Al Jurf: taljurf.fedora@gmail.com
+            109863: 'taljurf@fedoraproject.org',
+            # Josh Kayse: jokajak@gmail.com
+            148243: 'jokajak@fedoraproject.org',
+            # Behdad Esfahbod: fedora@behdad.org
+            100102: 'behdad@fedoraproject.org',
+            # Daniel Bruno: danielbrunos@gmail.com
+            101608: 'dbruno@fedoraproject.org',
+            # Beth Lynn Eicher: bethlynneicher@gmail.com
+            148706: 'bethlynn@fedoraproject.org',
+            # Andre Robatino: andre.robatino@verizon.net
+            114970: 'robatino@fedoraproject.org',
+            # Jeff Sheltren: jeff@tag1consulting.com
+            100058: 'sheltren@fedoraproject.org',
+            # Josh Boyer: jwboyer@gmail.com
+            100115: 'jwboyer@redhat.com',
+            # Matthew Miller: mattdm@mattdm.org
+            100042: 'mattdm@redhat.com',
+            # Jamie Nguyen: j@jamielinux.com
+            160587: 'jamielinux@fedoraproject.org',
+            # Nikos Roussos: nikos@roussos.cc
+            144436: 'comzeradd@fedoraproject.org',
+            # Benedikt Schäfer: benedikt@schaefer-flieden.de
+            154726: 'ib54003@fedoraproject.org',
+            # Ricky Elrod: codeblock@elrod.me
+            139137: 'relrod@redhat.com',
+            # David Xie: david.scriptfan@gmail.com
+            167133: 'davidx@fedoraproject.org',
+            # Felix Schwarz: felix.schwarz@oss.schwarz.eu
+            103551: 'fschwarz@fedoraproject.org',
+            # Martin Holec: martix@martix.names
+            137561: 'mholec@redhat.com',
+        }
         # A few people have an email account that is used in owners.list but
         # have setup a bugzilla account for their primary account system email
         # address now.  Map these here.
         self.__alternate_email = {
-                # Damien Durand: splinux25@gmail.com
-                'splinux@fedoraproject.org': 100406,
-                # Kevin Fenzi: kevin@tummy.com
-                'kevin-redhat-bugzilla@tummy.com': 100037,
-                }
+            # Damien Durand: splinux25@gmail.com
+            'splinux@fedoraproject.org': 100406,
+            # Kevin Fenzi: kevin@tummy.com
+            'kevin-redhat-bugzilla@tummy.com': 100037,
+        }
         for bugzilla_map in self.__bugzilla_email.items():
             self.__alternate_email[bugzilla_map[1]] = bugzilla_map[0]
 
@@ -276,7 +287,8 @@ class AccountSystem(BaseClient):
     def _set_insecure(self, insecure):
         self._insecure = insecure
         self.proxy = FasProxyClient(self.base_url, useragent=self.useragent,
-                session_as_cookie=False, debug=self.debug, insecure=insecure)
+                                    session_as_cookie=False, debug=self.debug,
+                                    insecure=insecure)
         return insecure
     #: If this attribute is set to True, do not check server certificates
     #: against their CA's.  This means that man-in-the-middle attacks are
@@ -321,21 +333,25 @@ class AccountSystem(BaseClient):
             'apply_rules': apply_rules
         }
 
-        request = self.send_request('/group/create/%s/%s/%s/%s' % (
+        request = self.send_request(
+            '/group/create/%s/%s/%s/%s' % (
                 urllib.quote(name),
                 urllib.quote(display_name),
                 urllib.quote(owner),
                 urllib.quote(group_type)),
-                                    req_params=req_params,
-                                    auth=True)
+            req_params=req_params,
+            auth=True
+        )
         return request
 
-
     def group_by_id(self, group_id):
         '''Returns a group object based on its id'''
         params = {'group_id': int(group_id)}
-        request = self.send_request('json/group_by_id', auth = True,
-                req_params = params)
+        request = self.send_request(
+            'json/group_by_id',
+            auth=True,
+            req_params=params
+        )
         if request['success']:
             return request['group']
         else:
@@ -344,12 +360,16 @@ class AccountSystem(BaseClient):
     def group_by_name(self, groupname):
         '''Returns a group object based on its name'''
         params = {'groupname': groupname}
-        request = self.send_request('json/group_by_name', auth = True,
-                req_params = params)
+        request = self.send_request(
+            'json/group_by_name',
+            auth=True,
+            req_params=params
+        )
         if request['success']:
             return request['group']
         else:
-            raise AppError(message='FAS server unable to retrieve group'
+            raise AppError(
+                message='FAS server unable to retrieve group'
                 ' %(group)s' % {'group': to_bytes(groupname)},
                 name='FASError')
 
@@ -370,10 +390,10 @@ class AccountSystem(BaseClient):
             Return a Bunch instead of a DictContainer
         '''
         request = self.send_request('/group/dump/%s' %
-                urllib.quote(groupname), auth=True)
+                                    urllib.quote(groupname), auth=True)
 
-        return [Bunch(username=user[0], role_type=user[3])
-                    for user in request['people']]
+        return [Bunch(username=user[0],
+                      role_type=user[3]) for user in request['people']]
 
     ### People ###
 
@@ -382,21 +402,24 @@ class AccountSystem(BaseClient):
         person_id = int(person_id)
         params = {'person_id': person_id}
         request = self.send_request('json/person_by_id', auth=True,
-                req_params=params)
+                                    req_params=params)
 
         if request['success']:
             if person_id in self.__bugzilla_email:
                 request['person']['bugzilla_email'] = \
-                        self.__bugzilla_email[person_id]
+                    self.__bugzilla_email[person_id]
             else:
-                request['person']['bugzilla_email'] = request['person']['email']
-            # In a devel version of FAS, membership info was returned separately
+                request['person']['bugzilla_email'] = \
+                    request['person']['email']
+
+            # In a devel version of FAS, membership info was returned
+            # separately
             # This was later corrected (can remove this code at some point)
             if 'approved' in request:
                 request['person']['approved_memberships'] = request['approved']
             if 'unapproved' in request:
                 request['person']['unapproved_memberships'] = \
-                        request['unapproved']
+                    request['unapproved']
             return request['person']
         else:
             return dict()
@@ -404,8 +427,10 @@ class AccountSystem(BaseClient):
     def person_by_username(self, username):
         '''Returns a person object based on its username'''
         params = {'username': username}
-        request = self.send_request('json/person_by_username', auth = True,
-                req_params = params)
+        request = self.send_request(
+            'json/person_by_username',
+            auth=True,
+            req_params=params)
 
         if request['success']:
             person = request['person']
@@ -413,13 +438,14 @@ class AccountSystem(BaseClient):
                 person['bugzilla_email'] = self.__bugzilla_email[person['id']]
             else:
                 person['bugzilla_email'] = person['email']
-            # In a devel version of FAS, membership info was returned separately
+            # In a devel version of FAS, membership info was returned
+            # separately
             # This was later corrected (can remove this code at some point)
             if 'approved' in request:
                 request['person']['approved_memberships'] = request['approved']
             if 'unapproved' in request:
                 request['person']['unapproved_memberships'] = \
-                        request['unapproved']
+                    request['unapproved']
             return person
         else:
             return dict()
@@ -437,10 +463,12 @@ class AccountSystem(BaseClient):
         :kwarg default: If the service does not have a avatar image for the
             email address, this url is returned instead.  Default:
             the fedora logo at the specified size.
-        :kwarg lookup_email:  If true, use the email from FAS, otherwise just
-            append @fedoraproject.org to the username.  Note that this will be
-            much slower if lookup_email is set to True since we'd have to make
-            a query against FAS itself.
+        :kwarg lookup_email:  If true, use the email from FAS for gravatar.com
+            lookups, otherwise just append @fedoraproject.org to the username.
+            For libravatar.org lookups, this is ignored.  The openid identifier
+            of the user is used instead.
+            Note that gravatar.com lookups will be much slower if lookup_email
+            is set to True since we'd have to make a query against FAS itself.
         :kwarg service: One of 'libravatar' or 'gravatar'.
             Default: 'libravatar'.
         :raises ValueError: if the size parameter is not allowed or if the
@@ -460,12 +488,17 @@ class AccountSystem(BaseClient):
             urls with the email in fas or username@fedoraproject.org
         .. versionchanged: 0.3.33
             Renamed from `gravatar_url` to `avatar_url`
+        .. versionchanged: 0.3.34
+            Updated libravatar to use the user's openid identifier.
         '''
 
         if size not in self._valid_avatar_sizes:
-            raise ValueError('Size %(size)i disallowed.  Must be in'
-                ' %(valid_sizes)r' % { 'size': size,
-                    'valid_sizes': self._valid_avatar_sizes})
+            raise ValueError(
+                'Size %(size)i disallowed.  Must be in %(valid_sizes)r' % {
+                    'size': size,
+                    'valid_sizes': self._valid_avatar_sizes
+                }
+            )
 
         # If our caller explicitly requested libravatar but they don't have
         # it installed, then we need to raise a nice error and let them know.
@@ -484,27 +517,32 @@ class AccountSystem(BaseClient):
 
         # Just double check to make sure they didn't pass us a bogus service.
         if service not in self._valid_avatar_services:
-            raise ValueError('Service %(service)r disallowed.  Must be in'
-                ' %(valid_services)r' % { 'service': service,
-                    'valid_services': self._valid_avatar_services})
+            raise ValueError(
+                'Service %(service)r disallowed. '
+                'Must be in %(valid_services)r' % {
+                    'service': service,
+                    'valid_services': self._valid_avatar_services
+                }
+            )
 
         if not default:
             default = "http://fedoraproject.org/static/images/" + \
-                    "fedora_infinity_%ix%i.png" % (size, size)
-
-        if lookup_email:
-            person = self.person_by_username(username)
-            email = person.get('email', 'no_email')
-        else:
-            email = "%s@fedoraproject.org" % username
+                      "fedora_infinity_%ix%i.png" % (size, size)
 
         if service == 'libravatar':
+            openid = 'http://%s.id.fedoraproject.org/' % username
             return libravatar.libravatar_url(
-                email=email,
+                openid=openid,
                 size=size,
                 default=default,
             )
         else:
+            if lookup_email:
+                person = self.person_by_username(username)
+                email = person.get('email', 'no_email')
+            else:
+                email = "%s@fedoraproject.org" % username
+
             query_string = urllib.urlencode({
                 's': size,
                 'd': default,
@@ -512,7 +550,8 @@ class AccountSystem(BaseClient):
 
             hash = md5(email).hexdigest()
 
-            return "http://www.gravatar.com/avatar/%s?%s" % (hash, query_string)
+            return "http://www.gravatar.com/avatar/%s?%s" % (
+                hash, query_string)
 
     def gravatar_url(self, *args, **kwargs):
         """ *Deprecated* - Use avatar_url.
@@ -525,7 +564,8 @@ class AccountSystem(BaseClient):
             Deprecated in favor of `avatar_url`.
         """
 
-        warnings.warn("gravatar_url is deprecated and will be removed in"
+        warnings.warn(
+            "gravatar_url is deprecated and will be removed in"
             " a future version.  Please port your code to use avatar_url(...,"
             " service='libravatar', ...)  instead",
             DeprecationWarning, stacklevel=2)
@@ -605,14 +645,14 @@ class AccountSystem(BaseClient):
         # Make sure we have a valid key value
         if key not in ('id', 'username', 'email'):
             raise KeyError('key must be one of "id", "username", or'
-                ' "email"')
+                           ' "email"')
 
         if fields:
             fields = list(fields)
             for field in fields:
                 if field not in USERFIELDS:
                     raise KeyError('%(field)s is not a valid field to'
-                        ' filter' % {'field': to_bytes(field)})
+                                   ' filter' % {'field': to_bytes(field)})
         else:
             fields = USERFIELDS
 
@@ -630,17 +670,22 @@ class AccountSystem(BaseClient):
                 unrequested_fields.append('email')
                 fields.append('email')
 
-        request = self.send_request('/user/list', req_params={'search': search,
-            'fields': [f for f in fields if f != 'bugzilla_email']}, auth=True)
+        request = self.send_request(
+            '/user/list',
+            req_params={
+                'search': search,
+                'fields': [f for f in fields if f != 'bugzilla_email']
+            },
+            auth=True)
 
         people = Bunch()
         for person in itertools.chain(request['people'],
-                request['unapproved_people']):
+                                      request['unapproved_people']):
             # Retrieve bugzilla_email from our list if necessary
             if 'bugzilla_email' in fields:
                 if person['id'] in self.__bugzilla_email:
                     person['bugzilla_email'] = \
-                            self.__bugzilla_email[person['id']]
+                        self.__bugzilla_email[person['id']]
                 else:
                     person['bugzilla_email'] = person['email']
 
@@ -664,7 +709,8 @@ class AccountSystem(BaseClient):
         .. versionchanged:: 0.3.21
             Return a Bunch instead of a DictContainer
         '''
-        warnings.warn("people_by_id() is deprecated and will be removed in"
+        warnings.warn(
+            "people_by_id() is deprecated and will be removed in"
             " 0.4.  Please port your code to use people_by_key(key='id',"
             " fields=['human_name', 'email', 'username', 'bugzilla_email'])"
             " instead", DeprecationWarning, stacklevel=2)
@@ -721,9 +767,13 @@ class AccountSystem(BaseClient):
             returned.
         '''
         request = self.send_request('config/list/%s/%s/%s' %
-                (username, application, attribute), auth=True)
+                                    (username, application, attribute),
+                                    auth=True)
         if 'exc' in request:
-            raise AppError(name = request['exc'], message = request['tg_flash'])
+            raise AppError(
+                name=request['exc'],
+                message=request['tg_flash']
+            )
 
         # Return the value if it exists, else None.
         if 'configs' in request and attribute in request['configs']:
@@ -743,10 +793,14 @@ class AccountSystem(BaseClient):
         :raises AppError: if the server returns an exception
         :returns: A dict mapping ``attribute`` to ``value``.
         '''
-        request = self.send_request('config/list/%s/%s/%s' %
-                (username, application, pattern), auth=True)
+        request = self.send_request(
+            'config/list/%s/%s/%s' %
+            (username, application, pattern),
+            auth=True)
         if 'exc' in request:
-            raise AppError(name = request['exc'], message = request['tg_flash'])
+            raise AppError(
+                name=request['exc'],
+                message=request['tg_flash'])
 
         return request['configs']
 
@@ -762,12 +816,15 @@ class AccountSystem(BaseClient):
         :arg value: The value to set this to
         :raises AppError: if the server returns an exception
         '''
-        request = self.send_request('config/set/%s/%s/%s' %
-                (username, application, attribute),
-                req_params={'value': value}, auth=True)
+        request = self.send_request(
+            'config/set/%s/%s/%s' %
+            (username, application, attribute),
+            req_params={'value': value}, auth=True)
 
         if 'exc' in request:
-            raise AppError(name = request['exc'], message = request['tg_flash'])
+            raise AppError(
+                name=request['exc'],
+                message=request['tg_flash'])
 
     def people_query(self, constraints=None, columns=None):
         '''Returns a list of dicts representing database rows
@@ -791,7 +848,8 @@ class AccountSystem(BaseClient):
         req_params['columns'] = ','.join(columns)
 
         try:
-            request = self.send_request('json/people_query',
+            request = self.send_request(
+                'json/people_query',
                 req_params=req_params, auth=True)
             if request['success']:
                 return request['data']
@@ -841,12 +899,14 @@ class AccountSystem(BaseClient):
             params['force_refresh'] = True
 
         try:
-            request = self.send_request('json/fas_client/group_data',
+            request = self.send_request(
+                'json/fas_client/group_data',
                 req_params=params, auth=True)
             if request['success']:
                 return request['data']
             else:
-                raise AppError(message='FAS server unable to retrieve'
+                raise AppError(
+                    message='FAS server unable to retrieve'
                     ' group members', name='FASError')
         except FedoraServiceError:
             raise
@@ -868,8 +928,8 @@ class AccountSystem(BaseClient):
             if request['success']:
                 return request['data']
             else:
-                raise AppError(message='FAS server unable to retrieve user'
+                raise AppError(
+                    message='FAS server unable to retrieve user'
                     ' information', name='FASError')
         except FedoraServiceError:
             raise
-
