@@ -3,17 +3,17 @@
 #
 # Copyright 2008-2009  Red Hat, Inc.
 # This file is part of python-fedora
-# 
+#
 # python-fedora is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
 # version 2.1 of the License, or (at your option) any later version.
-# 
+#
 # python-fedora is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # Lesser General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU Lesser General Public
 # License along with python-fedora; if not, see <http://www.gnu.org/licenses/>
 #
@@ -35,37 +35,41 @@ from fedora import _
 
 MEDIAWIKI_DATEFORMAT = "%Y-%m-%dT%H:%M:%SZ"
 
+
 class Wiki(BaseClient):
     api_high_limits = False
 
     def __init__(self, base_url='https://fedoraproject.org/w/',
-            *args, **kwargs):
+                 *args, **kwargs):
         super(Wiki, self).__init__(base_url, *args, **kwargs)
 
     def get_recent_changes(self, now, then, limit=500):
         """ Get recent wiki changes from `now` until `then` """
-        data = self.send_request('api.php', req_params={
-                'list'    : 'recentchanges',
-                'action'  : 'query',
-                'format'  : 'json',
-                'rcprop'  : 'user|title',
-                'rcend'   : then.isoformat().split('.')[0] + 'Z',
-                'rclimit' : limit,
-                })
+        data = self.send_request(
+            'api.php', req_params={
+                'list': 'recentchanges',
+                'action': 'query',
+                'format': 'json',
+                'rcprop': 'user|title',
+                'rcend': then.isoformat().split('.')[0] + 'Z',
+                'rclimit': limit,
+            })
         if 'error' in data:
             raise Exception(data['error']['info'])
         return data['query']['recentchanges']
 
     def login(self, username, password):
         data = self.send_request('api.php', req_params={
-                'action': 'login',
-                'format': 'json',
-                'lgname': username,
-                'lgpassword': password,
-                })
+            'action': 'login',
+            'format': 'json',
+            'lgname': username,
+            'lgpassword': password,
+        })
         if 'lgtoken' not in data.get('login', {}):
-            raise AuthError('Login failed: %(data)s' %
-                    {'data':to_bytes(data)})
+            raise AuthError(
+                'Login failed: %(data)s' % {
+                    'data': to_bytes(data)
+                })
         #self.session_id = data['login']['lgtoken']
         #self.username = data['login']['lgusername']
         self.check_api_limits()
@@ -74,13 +78,13 @@ class Wiki(BaseClient):
     def check_api_limits(self):
         """ Checks whether you have the 'apihighlimits' right or not. """
         data = self.send_request('api.php', req_params={
-                'action': 'query',
-                'meta': 'userinfo',
-                'uiprop': 'rights',
-                'format': 'json',
-                })
+            'action': 'query',
+            'meta': 'userinfo',
+            'uiprop': 'rights',
+            'format': 'json',
+        })
         self.api_high_limits = "apihighlimits" in \
-                data['query']['userinfo']['rights']
+                               data['query']['userinfo']['rights']
         return self.api_high_limits
 
     def print_recent_changes(self, days=7, show=10):
@@ -91,7 +95,8 @@ class Wiki(BaseClient):
         num_changes = len(changes)
         print _(u"%d wiki changes in the past week") % num_changes
         if num_changes == 500:
-            print _(u"""Warning: Number of changes reaches the API return limit.
+            print _(
+                u"""Warning: Number of changes reaches the API return limit.
 You will not get the complete list of changes unless
 you run this script using a 'bot' account.""")
 
@@ -119,35 +124,37 @@ you run this script using a 'bot' account.""")
                             title=True, ignore_imported_revs=True,
                             ignore_wikibot=False, callback=None):
         """
-        Fetch data for all revisions. This could take a long time. You can start
-        at a specific revision by modifying the 'start' keyword argument.
+        Fetch data for all revisions. This could take a long time. You can
+        start at a specific revision by modifying the 'start' keyword argument.
 
         To ignore revisions made by "ImportUser" and "Admin" set
-        ignore_imported_revs to True (this is the default). To ignore edits made
-        by Wikibot set ignore_wikibot to True (False is the default).
+        ignore_imported_revs to True (this is the default). To ignore edits
+        made by Wikibot set ignore_wikibot to True (False is the default).
 
         Modifying the remainder of the keyword arguments will return less/more
         data.
         """
         # first we need to get the latest revision id
-        change = self.send_request('api.php', req_params={
+        change = self.send_request(
+            'api.php', req_params={
                 'list': 'recentchanges',
                 'action': 'query',
                 'format': 'json',
                 'rcprop': 'ids',
                 'rclimit': 1,
                 'rctype': 'edit|new',
-        })
+            }
+        )
         latest_revid = change['query']['recentchanges'][0]['revid']
         # now we loop through all the revisions we want
         rvprop_list = {
-                'flags': flags,
-                'timestamp': timestamp,
-                'user': True,
-                'size': size,
-                'comment': comment,
-                'content': content,
-                'ids': True,
+            'flags': flags,
+            'timestamp': timestamp,
+            'user': True,
+            'size': size,
+            'comment': comment,
+            'content': content,
+            'ids': True,
         }
         rvprop = '|'.join([key for key in rvprop_list if rvprop_list[key]])
         revs_to_get = range(start, latest_revid)
@@ -159,17 +166,19 @@ you run this script using a 'bot' account.""")
         for i in xrange(0, len(revs_to_get), limit):
             revid_list = revs_to_get[i:i+limit]
             revid_str = '|'.join([str(rev) for rev in revid_list])
-            data = self.send_request('api.php', req_params={
+            data = self.send_request(
+                'api.php', req_params={
                     'action': 'query',
                     'prop': 'revisions',
                     'rvprop': rvprop,
                     'revids': revid_str,
                     'format': 'json',
-            })
+                }
+            )
             if 'pages' not in data['query'].keys():
                 continue
             if 'badrevids' in data['query'].keys():
-                [revs_to_get.remove(i['revid']) for i in \
+                [revs_to_get.remove(i['revid']) for i in
                  data['query']['badrevids'].values()]
             for pageid in data['query']['pages']:
                 page = data['query']['pages'][pageid]
