@@ -39,7 +39,7 @@ import pkg_resources
 from beaker.cache import Cache
 from bunch import Bunch
 from kitchen.text.converters import to_bytes, exception_to_bytes
-from paste.httpexceptions import HTTPFound, HTTPForbidden
+from paste.httpexceptions import HTTPFound
 from repoze.who.middleware import PluggableAuthenticationMiddleware
 from repoze.who.classifiers import default_request_classifier
 from repoze.who.classifiers import default_challenge_decider
@@ -49,7 +49,6 @@ from repoze.who.plugins.friendlyform import FriendlyFormPlugin
 from paste.request import parse_dict_querystring, parse_formvars
 import webob
 
-from fedora import _
 from fedora.client import AuthError
 from fedora.client.fasproxy import FasProxyClient
 from fedora.wsgi.csrf import CSRFMetadataProvider, CSRFProtectionMiddleware
@@ -57,20 +56,26 @@ from fedora.wsgi.csrf import CSRFMetadataProvider, CSRFProtectionMiddleware
 log = logging.getLogger(__name__)
 
 FAS_URL = 'https://admin.fedoraproject.org/accounts/'
-FAS_CACHE_TIMEOUT = 900 # 15 minutes (FAS visits timeout after 20)
+FAS_CACHE_TIMEOUT = 900  # 15 minutes (FAS visits timeout after 20)
 
 fas_cache = Cache('fas_repozewho_cache', type='memory')
 
-def fas_request_classifier(environ): 
-    classifier = default_request_classifier(environ) 
-    if classifier == 'browser': 
-        request = webob.Request(environ) 
-        if not request.accept.best_match(['application/xhtml+xml','text/html']): 
-            classifier = 'app' 
-    return classifier 
 
-def make_faswho_middleware(app, log_stream=None, login_handler='/login_handler',
-        login_form_url='/login', logout_handler='/logout_handler',
+def fas_request_classifier(environ):
+    classifier = default_request_classifier(environ)
+    if classifier == 'browser':
+        request = webob.Request(environ)
+        if not request.accept.best_match(
+                ['application/xhtml+xml', 'text/html']):
+            classifier = 'app'
+    return classifier
+
+
+def make_faswho_middleware(
+        app, log_stream=None,
+        login_handler='/login_handler',
+        login_form_url='/login',
+        logout_handler='/logout_handler',
         post_login_url='/post_login', post_logout_url=None, fas_url=FAS_URL,
         insecure=False, ssl_cookie=True, httponly=True):
     '''
@@ -99,10 +104,11 @@ def make_faswho_middleware(app, log_stream=None, login_handler='/login_handler',
     # need to make this a keyword arg and then check it here to make it act
     # like a positional arg.
     if not log_stream:
-        raise TypeError('log_stream must be set when calling make_fasauth_middleware()')
+        raise TypeError(
+            'log_stream must be set when calling make_fasauth_middleware()')
 
     faswho = FASWhoPlugin(fas_url, insecure=insecure, ssl_cookie=ssl_cookie,
-            httponly=httponly)
+                          httponly=httponly)
     csrf_mdprovider = CSRFMetadataProvider()
 
     form = FriendlyFormPlugin(login_form_url,
@@ -113,12 +119,16 @@ def make_faswho_middleware(app, log_stream=None, login_handler='/login_handler',
                               rememberer_name='fasident',
                               charset='utf-8')
 
-    form.classifications = { IIdentifier: ['browser'],
-                             IChallenger: ['browser'] } # only for browser
+    form.classifications = {IIdentifier: ['browser'],
+                            IChallenger: ['browser']}  # only for browser
 
     basicauth = BasicAuthPlugin('repoze.who')
 
-    identifiers = [('form', form), ('fasident', faswho), ('basicauth', basicauth)]
+    identifiers = [
+        ('form', form),
+        ('fasident', faswho),
+        ('basicauth', basicauth)
+    ]
     authenticators = [('fasauth', faswho)]
     challengers = [('form', form), ('basicauth', basicauth)]
     mdproviders = [('fasmd', faswho), ('csrfmd', csrf_mdprovider)]
@@ -128,22 +138,23 @@ def make_faswho_middleware(app, log_stream=None, login_handler='/login_handler',
 
     app = CSRFProtectionMiddleware(app)
     app = PluggableAuthenticationMiddleware(
-            app,
-            identifiers,
-            authenticators,
-            challengers,
-            mdproviders,
-            fas_request_classifier,
-            default_challenge_decider,
-            log_stream = log_stream,
-            )
+        app,
+        identifiers,
+        authenticators,
+        challengers,
+        mdproviders,
+        fas_request_classifier,
+        default_challenge_decider,
+        log_stream=log_stream,
+    )
 
     return app
 
+
 class FASWhoPlugin(object):
 
     def __init__(self, url, insecure=False, session_cookie='tg-visit',
-            ssl_cookie=True, httponly=True):
+                 ssl_cookie=True, httponly=True):
         self.url = url
         self.insecure = insecure
         self.fas = FasProxyClient(url, insecure=insecure)
@@ -181,7 +192,7 @@ class FASWhoPlugin(object):
         # we don't define permissions since we don't have any peruser data
         # though other services may wish to add another metadata plugin to do
         # so
-        if not user_data[1].has_key('permissions'):
+        if not 'permissions' in user_data[1]:
             user_data[1]['permissions'] = set()
 
         # we keep the approved_memberships list because there is also an
@@ -196,7 +207,7 @@ class FASWhoPlugin(object):
         user_data[1]['groups'] = groups
         # If we have information on the user, cache it for later
         fas_cache.set_value(user_data[1]['username'], user_data,
-                expiretime=FAS_CACHE_TIMEOUT)
+                            expiretime=FAS_CACHE_TIMEOUT)
         return user_data
 
     def identify(self, environ):
@@ -222,7 +233,10 @@ class FASWhoPlugin(object):
         if form.get('login', None) == 'Login' and \
                 'user_name' in form and \
                 'password' in form:
-            identity = {'login': form['user_name'], 'password': form['password']}
+            identity = {
+                'login': form['user_name'],
+                'password': form['password']
+            }
             keys = ('login', 'password', 'user_name')
             for k in keys:
                 if k in req.GET:
@@ -235,11 +249,12 @@ class FASWhoPlugin(object):
             return None
 
         log.info('Request identify for cookie %(cookie)s' %
-                {'cookie': to_bytes(cookie)})
+                 {'cookie': to_bytes(cookie)})
         try:
-            user_data = self._retrieve_user_info(environ,
-                    auth_params={'session_id': cookie})
-        except Exception, e: # pylint:disable-msg=W0703
+            user_data = self._retrieve_user_info(
+                environ,
+                auth_params={'session_id': cookie})
+        except Exception as e:  # pylint:disable-msg=W0703
             # For any exceptions, returning None means we failed to identify
             log.warning(e)
             return None
@@ -249,19 +264,18 @@ class FASWhoPlugin(object):
 
         # Preauthenticated
         identity = {'repoze.who.userid': user_data[1]['username'],
-                'login': user_data[1]['username'],
-                'password': user_data[1]['password']}
+                    'login': user_data[1]['username'],
+                    'password': user_data[1]['password']}
         return identity
 
     def remember(self, environ, identity):
         log.info('In remember()')
-        req = webob.Request(environ)
         result = []
 
         user_data = fas_cache.get_value(identity['login'])
         try:
             session_id = user_data[0]
-        except Exception, e:
+        except Exception:
             return None
 
         set_cookie = ['%s=%s; Path=/;' % (self.session_cookie, session_id)]
@@ -276,7 +290,6 @@ class FASWhoPlugin(object):
     def forget(self, environ, identity):
         log.info('In forget()')
         # return a expires Set-Cookie header
-        req = webob.Request(environ)
 
         user_data = fas_cache.get_value(identity['login'])
         try:
@@ -285,14 +298,14 @@ class FASWhoPlugin(object):
             return None
 
         log.info('Forgetting login data for cookie %(s_id)s' %
-                {'s_id': to_bytes(session_id)})
+                 {'s_id': to_bytes(session_id)})
 
         self.fas.logout(session_id)
 
         result = []
         fas_cache.remove_value(key=identity['login'])
         expired = '%s=\'\'; Path=/; Expires=Sun, 10-May-1971 11:59:00 GMT'\
-                % self.session_cookie
+                  % self.session_cookie
         result.append(('Set-Cookie', expired))
         return result
 
@@ -309,7 +322,6 @@ class FASWhoPlugin(object):
                                 'came_from=' + quote_plus(came_from))
             environ['repoze.who.application'] = err_app
 
-
         err_goto = '/login'
         default_came_from = '/'
         if 'SCRIPT_NAME' in environ:
@@ -324,7 +336,7 @@ class FASWhoPlugin(object):
 
         try:
             auth_params = {'username': identity['login'],
-                    'password': identity['password']}
+                           'password': identity['password']}
         except KeyError:
             try:
                 auth_params = {'session_id': identity['session_id']}
@@ -335,11 +347,11 @@ class FASWhoPlugin(object):
 
         try:
             user_data = self._retrieve_user_info(environ, auth_params)
-        except AuthError, e:
+        except AuthError as e:
             set_error('Authentication failed: %s' % exception_to_bytes(e))
             log.warning(e)
             return None
-        except Exception, e:
+        except Exception as e:
             set_error('Unknown auth failure: %s' % exception_to_bytes(e))
             return None
 
@@ -351,15 +363,14 @@ class FASWhoPlugin(object):
             except ValueError:
                 set_error('user information from fas not in expected format!')
                 return None
-            except Exception, e:
+            except Exception:
                 pass
         set_error('An unknown error happened when trying to log you in.'
-                ' Please try again.')
+                  ' Please try again.')
         return None
 
     def add_metadata(self, environ, identity):
         log.info('In add_metadata')
-        req = webob.Request(environ)
 
         if identity.get('error'):
             log.info('Error exists in session, no need to set metadata')
@@ -372,8 +383,9 @@ class FASWhoPlugin(object):
         del plugin_user_info
 
         user = identity.get('repoze.who.userid')
-        (session_id, user_info) = fas_cache.get_value(key=user,
-                expiretime=FAS_CACHE_TIMEOUT)
+        (session_id, user_info) = fas_cache.get_value(
+            key=user,
+            expiretime=FAS_CACHE_TIMEOUT)
 
         #### FIXME: Deprecate this line!!!
         # If we make a new version of fas.who middleware, get rid of saving
@@ -398,7 +410,8 @@ class FASWhoPlugin(object):
             environ['repoze.what.credentials'] = {}
 
         environ['repoze.what.credentials']['groups'] = user_info['groups']
-        environ['repoze.what.credentials']['permissions'] = user_info['permissions']
+        permissions = user_info['permissions']
+        environ['repoze.what.credentials']['permissions'] = permissions
 
         # Adding the userid:
         userid = identity['repoze.who.userid']
